@@ -15,8 +15,9 @@ use AI::Pathfinding::OptimizeMultiple::SimulationResults;
 use MooX qw/late/;
 
 use PDL;
+use Scalar::Util qw/ blessed /;
 
-our $VERSION = '0.0.12';
+our $VERSION = '0.0.13';
 
 has chosen_scans => (isa => 'ArrayRef', is => 'rw');
 has _iter_idx => (isa => 'Int', is => 'rw', default => sub { 0; },);
@@ -319,14 +320,14 @@ sub calc_meta_scan
     else
     {
         $err = Exception::Class->caught();
-        if (ref($err))
+        if ($err)
         {
+            if (not ( blessed $err && $err->can('rethrow')))
+            {
+                die $err;
+            }
             $err->rethrow;
         }
-        elsif ($err)
-        {
-            die $err;
-        }
     }
 
     return;
@@ -667,7 +668,7 @@ set of initial conditions (for better average performance).
 
 =head1 VERSION
 
-version 0.0.12
+version 0.0.13
 
 =head1 SYNOPSIS
 
@@ -887,7 +888,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=AI-Pathfinding-OptimizeMultiple>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -919,7 +920,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/AI-Pathfinding-OptimizeMultiple>
+L<http://cpants.cpanauthors.org/dist/AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -950,7 +951,7 @@ L<http://deps.cpantesters.org/?module=AI::Pathfinding::OptimizeMultiple>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-ai-pathfinding-optimizemultiple at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=AI-Pathfinding-OptimizeMultiple>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=AI-Pathfinding-OptimizeMultiple>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
