@@ -11,7 +11,7 @@ use IO::File;
 use AI::Pathfinding::OptimizeMultiple;
 use AI::Pathfinding::OptimizeMultiple::PostProcessor;
 
-our $VERSION = '0.0.12';
+our $VERSION = '0.0.13';
 
 # TODO : restore later.
 # use MyInput;
@@ -589,7 +589,7 @@ AI::Pathfinding::OptimizeMultiple::App::CmdLine - the command line application c
 
 =head1 VERSION
 
-version 0.0.12
+version 0.0.13
 
 =head1 SUBROUTINES/METHODS
 
@@ -700,7 +700,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=AI-Pathfinding-OptimizeMultiple>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -732,7 +732,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/AI-Pathfinding-OptimizeMultiple>
+L<http://cpants.cpanauthors.org/dist/AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -763,7 +763,7 @@ L<http://deps.cpantesters.org/?module=AI::Pathfinding::OptimizeMultiple>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-ai-pathfinding-optimizemultiple at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=AI-Pathfinding-OptimizeMultiple>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=AI-Pathfinding-OptimizeMultiple>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
