@@ -9,7 +9,7 @@ use MooX qw/late/;
 
 use PDL ();
 
-our $VERSION = '0.0.12';
+our $VERSION = '0.0.13';
 
 use vars (qw(@fields));
 
@@ -174,7 +174,7 @@ AI::Pathfinding::OptimizeMultiple::IterState - iteration state object.
 
 =head1 VERSION
 
-version 0.0.12
+version 0.0.13
 
 =head1 SUBROUTINES/METHODS
 
@@ -292,7 +292,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=AI-Pathfinding-OptimizeMultiple>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -324,7 +324,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/AI-Pathfinding-OptimizeMultiple>
+L<http://cpants.cpanauthors.org/dist/AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -355,7 +355,7 @@ L<http://deps.cpantesters.org/?module=AI::Pathfinding::OptimizeMultiple>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-ai-pathfinding-optimizemultiple at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=AI-Pathfinding-OptimizeMultiple>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=AI-Pathfinding-OptimizeMultiple>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
