@@ -7,7 +7,7 @@ use 5.012;
 
 use MooX qw/late/;
 
-our $VERSION = '0.0.12';
+our $VERSION = '0.0.13';
 
 has _should_do_rle => (isa => 'Bool', is => 'ro', init_arg => 'do_rle', required => 1);
 has _offset_quotas => (isa => 'Bool', is => 'ro', init_arg => 'offset_quotas', required => 1);
@@ -79,7 +79,7 @@ AI::Pathfinding::OptimizeMultiple::PostProcessor - post-processor.
 
 =head1 VERSION
 
-version 0.0.12
+version 0.0.13
 
 =head1 SUBROUTINES/METHODS
 
@@ -177,7 +177,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=AI-Pathfinding-OptimizeMultiple>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -209,7 +209,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/AI-Pathfinding-OptimizeMultiple>
+L<http://cpants.cpanauthors.org/dist/AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -240,7 +240,7 @@ L<http://deps.cpantesters.org/?module=AI::Pathfinding::OptimizeMultiple>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-ai-pathfinding-optimizemultiple at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=AI-Pathfinding-OptimizeMultiple>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=AI-Pathfinding-OptimizeMultiple>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
